@@ -1,6 +1,6 @@
 ## -*- mode: Perl -*-
 ##
-## Copyright (c) 2012, 2013, 2015, 2016 The University of Utah
+## Copyright (c) 2012, 2013, 2015 The University of Utah
 ## All rights reserved.
 ##
 ## This file is distributed under the University of Illinois Open Source
@@ -43,8 +43,7 @@ sub count_instances ($$) {
 sub check_prereqs () {
     $ORIG_DIR = getcwd();
     my $path;
-    my $abs_bindir = abs_path(bindir);
-    if ((defined $abs_bindir) && ($FindBin::RealBin eq $abs_bindir)) {
+    if ($FindBin::RealBin eq abs_path(bindir)) {
 	# This script is in the installation directory.
 	# Use the installed `clang_delta'.
 	$path = libexecdir . "/clang_delta";
@@ -86,6 +85,11 @@ sub advance ($$$) {
     return \%sh;
 }
 
+sub advance_on_success ($$$) {
+    (my $cfile, my $which, my $state) = @_;
+    return $state;
+}
+
 sub round ($) {
     (my $n) = @_;
     return int ($n+0.5);
@@ -119,7 +123,7 @@ sub transform ($$$) {
 	if ($end > $instances) {
 	    $end = $instances;
 	}
-
+	
 	my $dec = $end - $index + 1;
 
 	my $cmd = qq{"$clang_delta" --transformation=$which --counter=$index --to-counter=$end $cfile};
@@ -139,8 +143,8 @@ sub transform ($$$) {
 	    } else {
 		unlink $tmpfile;
 		return ($ERROR, "crashed: $cmd");
-	    }
-	}
+	    }   
+	} 	
 	File::Copy::move($tmpfile, $cfile);
     } else {
       rechunk:
