@@ -1,6 +1,6 @@
 ## -*- mode: Perl -*-
 ##
-## Copyright (c) 2015, 2016, 2019 The University of Utah
+## Copyright (c) 2015 The University of Utah
 ## All rights reserved.
 ##
 ## This file is distributed under the University of Illinois Open Source
@@ -25,8 +25,7 @@ my $options = "-B -x 2";
 
 sub check_prereqs () {
     my $path;
-    my $abs_bindir = abs_path(bindir);
-    if ((defined $abs_bindir) && ($FindBin::RealBin eq $abs_bindir)) {
+    if ($FindBin::RealBin eq abs_path(bindir)) {
 	# This script is in the installation directory.
 	# Use the installed `unifdef'.
 	$path = libexecdir . "/unifdef";
@@ -49,7 +48,7 @@ sub check_prereqs () {
 }
 
 sub new ($$) {
-    my $index = -1;
+    my $index = 0;
     return \$index;
 }
 
@@ -60,6 +59,11 @@ sub advance ($$$) {
     return \$index;
 }
 
+sub advance_on_success ($$$) {
+    (my $cfile, my $arg, my $state) = @_;
+    return $state;
+}
+
 sub transform ($$$) {
     (my $cfile, my $which, my $state) = @_;
     my $index = ${$state};
@@ -72,19 +76,6 @@ sub transform ($$$) {
     close INF;
     my @deflist = sort keys %defs;
     my $tmpfile = File::Temp::tmpnam();
-
-    # remove constant ifs
-    if ($index == -1) {
-	my $cmd = "$unifdef -k -o $tmpfile $cfile >/dev/null 2>&1";
-	runit ($cmd);
-	$index++;
-	if (compare($cfile, $tmpfile) == 0) {
-	    goto AGAIN;
-        }
-	File::Copy::move($tmpfile, $cfile);
-	return ($OK, \$index);
-    }
-
   AGAIN:
     print "index = $index\n" if $DEBUG;
     my $DU = (($index % 2) == 0) ? "-D" : "-U";
